@@ -1,6 +1,8 @@
-import urllib
+import openpyxl
+from xlsxhelper import get_workbook
+from fastutils import strutils
+
 from django.db import models
-from django.conf import settings as django_settings
 from django.contrib import admin
 from django.http import HttpResponse
 from django.http import HttpResponseRedirect
@@ -12,12 +14,10 @@ from django.utils import timezone
 from django.utils.http import urlquote
 from django_changelist_toolbar_admin.admin import DjangoChangelistToolbarAdmin
 from django_changelist_toolbar_admin.admin import Button
-import openpyxl
-from xlsxhelper import get_workbook
-from xlsxhelper import get_worksheet
+
 
 DEFAULT_FILENAME_TEMPLATE = "{model_name}-{year:04d}{month:02d}{day:02d}-{hour:02d}{minute:02d}{second:02d}.xlsx"
-
+XLSX_CELL_SIZE_MAX = 32*1024
 
 class Aggregate(object):
     pass
@@ -44,7 +44,7 @@ class Average(Aggregate):
     
     def final(self):
         if not self.count:
-            return empty
+            return self.empty
         else:
             return self.total / self.count
 
@@ -108,7 +108,7 @@ class DjangoSimpleExportAdmin(DjangoChangelistToolbarAdmin, admin.ModelAdmin):
         app_label = self.model._meta.app_label
         model_name = self.model._meta.model_name
         return [
-            path("simple-export/<code>/", self.admin_site.admin_view(self.django_simple_export_admin_export_view), name="{0}_{1}_simple_export".format(app_label, model_name)),
+            path("django-simple-export/<code>/", self.admin_site.admin_view(self.django_simple_export_admin_export_view), name="{0}_{1}_simple_export".format(app_label, model_name)),
         ] + super().get_urls()
 
     def django_simple_export_admin_export_view(self, request, code):
@@ -134,10 +134,7 @@ class DjangoSimpleExportAdmin(DjangoChangelistToolbarAdmin, admin.ModelAdmin):
         return HttpResponseRedirect(url)
 
     def django_simple_export_admin_get_django_simple_exports(self):
-        if hasattr(self, "django_simple_export_admin_exports"):
-            return self.django_simple_export_admin_exports
-        else:
-            return {}
+        return getattr(self, "django_simple_export_admin_exports", {})
 
     def django_simple_export_admin_get_filename(self, request, settings):
         filename_template = settings.get("filename", DEFAULT_FILENAME_TEMPLATE)
@@ -183,7 +180,19 @@ class DjangoSimpleExportAdmin(DjangoChangelistToolbarAdmin, admin.ModelAdmin):
         for loop_index, item in enumerate(items):
             for col_index, field_setting in enumerate(settings["fields"]):
                 value = self.django_simple_export_admin_get_field_value(item, field_setting, loop_index)
-                worksheet.cell(row_index+1, col_index+1).value = value
+                real_col_index = field_setting.get("col", col_index+1)
+                if not isinstance(real_col_index, (tuple, list, set)):
+                    worksheet.cell(row_index+1, real_col_index).value = value
+                else:
+                    # split value into multi cells
+                    if isinstance(real_col_index, set):
+                        real_col_index = list(real_col_index)
+                        real_col_index.sort()
+                    cell_size = field_setting.get("cell_size", XLSX_CELL_SIZE_MAX)
+                    values = strutils.chunk(value, cell_size)
+                    for tmp_index in range(len(values)):
+                        worksheet.cell(row_index+1, real_col_index[tmp_index]).value = values[tmp_index]
+                    # split value into multi cells end
                 self.django_simple_export_admin_calc_footer_value(footer_values, col_index, field_setting, value)
             row_index += 1
         # write footer
@@ -228,8 +237,6 @@ class DjangoSimpleExportAdmin(DjangoChangelistToolbarAdmin, admin.ModelAdmin):
             footer_values[col_index].push(value)
 
     def django_simple_export_admin_get_items(self, request):
-        list_display = ()
-        list_display_links = ()
         sortable_by = self.get_sortable_by(request)
         ChangeList = self.get_changelist(request)
         cl = ChangeList(
@@ -251,7 +258,7 @@ class DjangoSimpleExportAdmin(DjangoChangelistToolbarAdmin, admin.ModelAdmin):
 
     def django_simple_export_admin_is_model_field(self, field_name):
         try:
-            field = self.model._meta.get_field(field_name)
+            self.model._meta.get_field(field_name)
             return True
         except models.FieldDoesNotExist:
             return False
@@ -267,7 +274,7 @@ class DjangoSimpleExportAdmin(DjangoChangelistToolbarAdmin, admin.ModelAdmin):
                 if hasattr(item, "get_{}_display".format(field_name)):
                     field_value = getattr(item, "get_{}_display".format(field_name))()
                 else:
-                    field_value = getattr(item, field_name)
+                    field_value = getattr(item, field_name, None)
                     if field_name != settings["field"]:
                         for attr in settings["field"].split("__")[1:]:
                             if field_value:
